@@ -2,7 +2,6 @@ import logging
 
 from PySide import QtGui
 
-import spreads
 from spreads.plugin import HookPlugin
 import gui
 import gui_rc
@@ -15,12 +14,13 @@ class GuiCommand(HookPlugin):
     def add_command_parser(cls, rootparser):
         guiparser = rootparser.add_parser(
             'gui', help="Start the GUI wizard")
-        guiparser.set_defaults(func=wizard)
+        guiparser.set_defaults(subcommand=GuiCommand.wizard)
 
+    @staticmethod
+    def wizard(config):
+        logger.debug("Starting GUI")
+        app = QtGui.QApplication([])
 
-def wizard(args):
-    logger.debug("Starting GUI")
-    app = QtGui.QApplication([])
-    wizard = gui.SpreadsWizard(spreads.config)
-    wizard.show()
-    app.exec_()
+        wizard = gui.SpreadsWizard(config)
+        wizard.show()
+        app.exec_()
