@@ -1,37 +1,34 @@
 import logging
+import multiprocessing
+import os
 import re
 import subprocess
+import time
 import xml.etree.cElementTree as ET
 
-from concurrent import futures
-
 from spreads.plugin import HookPlugin, PluginOption
 from spreads.util import find_in_path, MissingDependencyException
+from spreads.vendor.pathlib import Path
 
 if not find_in_path('tesseract'):
     raise MissingDependencyException("Could not find executable `tesseract`"
                                      " in $PATH. Please install the"
                                      " appropriate package(s)!")
 
-AVAILABLE_LANGS = (subprocess.check_output(["tesseract", "--list-langs"],
-                                           stderr=subprocess.STDOUT)
-                   .split("\n")[1:-1])
-
 logger = logging.getLogger('spreadsplug.tesseract')
+try:
+    AVAILABLE_LANGS = (subprocess.check_output(["tesseract", "--list-langfoo"],
+                                               stderr=subprocess.STDOUT)
+                       .split("\n")[1:-1])
+except subprocess.CalledProcessError:
+    AVAILABLE_LANGS = [x.stem for x in
+                       Path('/usr/share/tesseract-ocr/tessdata')
+                       .glob('*.traineddata')]
 
 
 class TesseractPlugin(HookPlugin):
     __name__ = 'tesseract'
 
-    @classmethod
-    def add_arguments(cls, command, parser):
-        if command == 'postprocess':
-            parser.add_argument("--language", "-l",
-                                dest="language", default="eng",
-                                help="OCR language (3-letter language code)"
-                                     " [default: {0}]"
-                                     .format(AVAILABLE_LANGS[0]))
-
     @classmethod
     def configuration_template(cls):
         conf = {'language': PluginOption(value=AVAILABLE_LANGS,
@@ -41,17 +38,33 @@ class TesseractPlugin(HookPlugin):
         return conf
 
     def process(self, path):
+        def _clean_processes(procs):
+            for p in processes[:]:
+                if p.poll() is not None:
+                    processes.remove(p)
+
         ocr_lang = self.config['language'].get()
         logger.info("Performing OCR")
         logger.info("Language is \"{0}\"".format(ocr_lang))
         img_dir = path / 'done'
-        with futures.ProcessPoolExecutor() as executor:
-            for img in img_dir.glob('*.tif'):
-                executor.submit(
-                    subprocess.check_output,
-                    ["tesseract", unicode(img), unicode(img_dir / img.stem),
-                     "-l", ocr_lang, "hocr"], stderr=subprocess.STDOUT
-                )
+
+        processes = []
+        max_procs = multiprocessing.cpu_count()
+        FNULL = open(os.devnull, 'w')
+        for img in img_dir.glob('*.tif'):
+            # Wait until another process has finished
+            while len(processes) >= max_procs:
+                _clean_processes(processes)
+                time.sleep(0.01)
+            proc = subprocess.Popen(["tesseract", unicode(img),
+                                     unicode(img_dir / img.stem), "-l",
+                                     ocr_lang, "hocr"], stderr=FNULL,
+                                     stdout=FNULL)
+            processes.append(proc)
+        # Wait for remaining processes to finish
+        while processes:
+            _clean_processes(processes)
+
         # NOTE: This modifies the hOCR files to make them compatible with
         #       pdfbeads.
         #       See the following bugreport for more information:
